Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAlexander Pinzon Fernandez <apinzonf@gmail.com>2013-12-11 20:10:22 +0400
committerAlexander Pinzon Fernandez <apinzonf@gmail.com>2013-12-11 20:10:22 +0400
commit2658a3c1b44717f497f187a38000c804eb37bbba (patch)
treeee55c673feabced8b6ec8bf9a8aa4d82a3cda3db /source/blender/makesdna
parent4005cb1c6a63a217df0e887c741beee2c1359301 (diff)
parent09b859d03f0ee138c4273ef8460e91d9888387a1 (diff)
Merge branch 'master' into soc-2013-sketch_meshsoc-2013-sketch_mesh
Conflicts: release/scripts/addons source/blender/blenloader/intern/readfile.c source/blender/blenloader/intern/writefile.c source/blender/editors/object/object_modifier.c source/blender/makesrna/intern/rna_modifier.c source/blender/modifiers/intern/MOD_laplaciandeform.c
Diffstat (limited to 'source/blender/makesdna')
-rw-r--r--source/blender/makesdna/DNA_ID.h2
-rw-r--r--source/blender/makesdna/DNA_armature_types.h11
-rw-r--r--source/blender/makesdna/DNA_brush_types.h2
-rw-r--r--source/blender/makesdna/DNA_camera_types.h58
-rw-r--r--source/blender/makesdna/DNA_curve_types.h1
-rw-r--r--source/blender/makesdna/DNA_defs.h14
-rw-r--r--source/blender/makesdna/DNA_freestyle_types.h3
-rw-r--r--source/blender/makesdna/DNA_gpencil_types.h4
-rw-r--r--source/blender/makesdna/DNA_image_types.h31
-rw-r--r--source/blender/makesdna/DNA_lamp_types.h4
-rw-r--r--source/blender/makesdna/DNA_mesh_types.h6
-rw-r--r--source/blender/makesdna/DNA_meshdata_types.h6
-rw-r--r--source/blender/makesdna/DNA_modifier_types.h35
-rw-r--r--source/blender/makesdna/DNA_node_types.h18
-rw-r--r--source/blender/makesdna/DNA_object_types.h4
-rw-r--r--source/blender/makesdna/DNA_particle_types.h2
-rw-r--r--source/blender/makesdna/DNA_scene_types.h102
-rw-r--r--source/blender/makesdna/DNA_screen_types.h2
-rw-r--r--source/blender/makesdna/DNA_sequence_types.h68
-rw-r--r--source/blender/makesdna/DNA_smoke_types.h20
-rw-r--r--source/blender/makesdna/DNA_sound_types.h22
-rw-r--r--source/blender/makesdna/DNA_space_types.h11
-rw-r--r--source/blender/makesdna/DNA_tracking_types.h6
-rw-r--r--source/blender/makesdna/DNA_userdef_types.h44
-rw-r--r--source/blender/makesdna/DNA_view3d_types.h3
-rw-r--r--source/blender/makesdna/DNA_world_types.h16
-rw-r--r--source/blender/makesdna/intern/makesdna.c8
27 files changed, 356 insertions, 147 deletions
diff --git a/source/blender/makesdna/DNA_ID.h b/source/blender/makesdna/DNA_ID.h
index 1e145347bb3..af27ea921ce 100644
--- a/source/blender/makesdna/DNA_ID.h
+++ b/source/blender/makesdna/DNA_ID.h
@@ -111,12 +111,12 @@ typedef struct ID {
struct ID *newid;
struct Library *lib;
char name[66]; /* MAX_ID_NAME */
- short pad, us;
/**
* LIB_... flags report on status of the datablock this ID belongs
* to.
*/
short flag;
+ int us;
int icon_id, pad2;
IDProperty *properties;
} ID;
diff --git a/source/blender/makesdna/DNA_armature_types.h b/source/blender/makesdna/DNA_armature_types.h
index 4780b2e85de..b6d4a8c9db8 100644
--- a/source/blender/makesdna/DNA_armature_types.h
+++ b/source/blender/makesdna/DNA_armature_types.h
@@ -30,6 +30,7 @@
#ifndef __DNA_ARMATURE_TYPES_H__
#define __DNA_ARMATURE_TYPES_H__
+#include "DNA_defs.h"
#include "DNA_listBase.h"
#include "DNA_ID.h"
@@ -88,7 +89,7 @@ typedef struct bArmature {
* - from the user perspective active == last selected
* - active should be ignored when not visible (hidden layer) */
- Bone *act_bone; /* active bone (when not in editmode) */
+ Bone *act_bone; /* active bone */
struct EditBone *act_edbone; /* active editbone (in editmode) */
void *sketch; /* sketch struct for etch-a-ton */
@@ -156,6 +157,10 @@ typedef enum eArmature_DeformFlag {
ARM_DEF_INVERT_VGROUP = (1<<4)
} eArmature_DeformFlag;
+#if (DNA_DEPRECATED_GCC_POISON == 1)
+#pragma GCC poison ARM_DEF_B_BONE_REST
+#endif
+
/* armature->pathflag */
// XXX deprecated... old animation system (armature only viz)
typedef enum eArmature_PathFlag {
@@ -166,6 +171,10 @@ typedef enum eArmature_PathFlag {
ARM_PATH_KFNOS = (1<<4)
} eArmature_PathFlag;
+#if (DNA_DEPRECATED_GCC_POISON == 1)
+#pragma GCC poison ARM_PATH_FNUMS ARM_PATH_KFRAS ARM_PATH_HEADS ARM_PATH_ACFRA ARM_PATH_KFNOS
+#endif
+
/* armature->ghosttype */
// XXX deprecated... old animation system (armature only viz)
typedef enum eArmature_GhostType {
diff --git a/source/blender/makesdna/DNA_brush_types.h b/source/blender/makesdna/DNA_brush_types.h
index 824091dab32..86fa7058f97 100644
--- a/source/blender/makesdna/DNA_brush_types.h
+++ b/source/blender/makesdna/DNA_brush_types.h
@@ -140,7 +140,7 @@ typedef enum BrushFlags {
BRUSH_LOCK_SIZE = (1 << 20),
// BRUSH_TEXTURE_OVERLAY = (1 << 21), /* obsolete, use overlay_flags |= BRUSH_OVERLAY_PRIMARY instead */
BRUSH_EDGE_TO_EDGE = (1 << 22),
- BRUSH_RESTORE_MESH = (1 << 23),
+ BRUSH_DRAG_DOT = (1 << 23),
BRUSH_INVERSE_SMOOTH_PRESSURE = (1 << 24),
BRUSH_RANDOM_ROTATION = (1 << 25),
BRUSH_PLANE_TRIM = (1 << 26),
diff --git a/source/blender/makesdna/DNA_camera_types.h b/source/blender/makesdna/DNA_camera_types.h
index 1ece25c9f70..c99494ce00e 100644
--- a/source/blender/makesdna/DNA_camera_types.h
+++ b/source/blender/makesdna/DNA_camera_types.h
@@ -73,38 +73,50 @@ typedef struct Camera {
/* **************** CAMERA ********************* */
/* type */
-#define CAM_PERSP 0
-#define CAM_ORTHO 1
-#define CAM_PANO 2
+enum {
+ CAM_PERSP = 0,
+ CAM_ORTHO = 1,
+ CAM_PANO = 2,
+};
/* dtx */
-#define CAM_DTX_CENTER 1
-#define CAM_DTX_CENTER_DIAG 2
-#define CAM_DTX_THIRDS 4
-#define CAM_DTX_GOLDEN 8
-#define CAM_DTX_GOLDEN_TRI_A 16
-#define CAM_DTX_GOLDEN_TRI_B 32
-#define CAM_DTX_HARMONY_TRI_A 64
-#define CAM_DTX_HARMONY_TRI_B 128
+enum {
+ CAM_DTX_CENTER = (1 << 0),
+ CAM_DTX_CENTER_DIAG = (1 << 1),
+ CAM_DTX_THIRDS = (1 << 2),
+ CAM_DTX_GOLDEN = (1 << 3),
+ CAM_DTX_GOLDEN_TRI_A = (1 << 4),
+ CAM_DTX_GOLDEN_TRI_B = (1 << 5),
+ CAM_DTX_HARMONY_TRI_A = (1 << 6),
+ CAM_DTX_HARMONY_TRI_B = (1 << 7),
+};
/* flag */
-#define CAM_SHOWLIMITS 1
-#define CAM_SHOWMIST 2
-#define CAM_SHOWPASSEPARTOUT 4
-#define CAM_SHOWTITLESAFE 8
-#define CAM_SHOWNAME 16
-#define CAM_ANGLETOGGLE 32
-#define CAM_DS_EXPAND 64
-#define CAM_PANORAMA 128 /* deprecated */
-#define CAM_SHOWSENSOR 256
+enum {
+ CAM_SHOWLIMITS = (1 << 0),
+ CAM_SHOWMIST = (1 << 1),
+ CAM_SHOWPASSEPARTOUT = (1 << 2),
+ CAM_SHOWTITLESAFE = (1 << 3),
+ CAM_SHOWNAME = (1 << 4),
+ CAM_ANGLETOGGLE = (1 << 5),
+ CAM_DS_EXPAND = (1 << 6),
+ CAM_PANORAMA = (1 << 7), /* deprecated */
+ CAM_SHOWSENSOR = (1 << 8),
+};
+
+#if (DNA_DEPRECATED_GCC_POISON == 1)
+#pragma GCC poison CAM_PANORAMA
+#endif
/* yafray: dof sampling switch */
/* #define CAM_YF_NO_QMC 512 */ /* deprecated */
/* Sensor fit */
-#define CAMERA_SENSOR_FIT_AUTO 0
-#define CAMERA_SENSOR_FIT_HOR 1
-#define CAMERA_SENSOR_FIT_VERT 2
+enum {
+ CAMERA_SENSOR_FIT_AUTO = 0,
+ CAMERA_SENSOR_FIT_HOR = 1,
+ CAMERA_SENSOR_FIT_VERT = 2,
+};
#define DEFAULT_SENSOR_WIDTH 32.0f
#define DEFAULT_SENSOR_HEIGHT 18.0f
diff --git a/source/blender/makesdna/DNA_curve_types.h b/source/blender/makesdna/DNA_curve_types.h
index 0141c4b61db..24035464259 100644
--- a/source/blender/makesdna/DNA_curve_types.h
+++ b/source/blender/makesdna/DNA_curve_types.h
@@ -178,7 +178,6 @@ typedef struct Curve {
struct BoundBox *bb;
ListBase nurb; /* actual data, called splines in rna */
- ListBase disp; /* undeformed display list, used mostly for texture space calculation */
EditNurb *editnurb; /* edited data, not in file, use pointer so we can check for it */
diff --git a/source/blender/makesdna/DNA_defs.h b/source/blender/makesdna/DNA_defs.h
index 842543da174..fc9dd8f06a9 100644
--- a/source/blender/makesdna/DNA_defs.h
+++ b/source/blender/makesdna/DNA_defs.h
@@ -44,6 +44,20 @@
# endif
#endif
+
+/* poison pragma */
+#ifdef DNA_DEPRECATED_ALLOW
+# define DNA_DEPRECATED_GCC_POISON 0
+#else
+ /* enable the pragma if we can */
+# ifdef __GNUC__
+# define DNA_DEPRECATED_GCC_POISON 1
+# else
+# define DNA_DEPRECATED_GCC_POISON 0
+# endif
+#endif
+
+
/* hrmf, we need a better include then this */
#include "../blenlib/BLI_sys_types.h" /* needed for int64_t only! */
diff --git a/source/blender/makesdna/DNA_freestyle_types.h b/source/blender/makesdna/DNA_freestyle_types.h
index db16fa37b86..195c7eb4841 100644
--- a/source/blender/makesdna/DNA_freestyle_types.h
+++ b/source/blender/makesdna/DNA_freestyle_types.h
@@ -32,6 +32,7 @@
* \ingroup DNA
*/
+#include "DNA_defs.h"
#include "DNA_listBase.h"
#ifdef __cplusplus
@@ -126,7 +127,7 @@ typedef struct FreestyleConfig {
ListBase modules;
int mode; /* scripting, editor */
- int raycasting_algorithm; /* XXX deprecated */
+ int raycasting_algorithm DNA_DEPRECATED;
int flags; /* suggestive contours, ridges/valleys, material boundaries */
float sphere_radius;
float dkr_epsilon;
diff --git a/source/blender/makesdna/DNA_gpencil_types.h b/source/blender/makesdna/DNA_gpencil_types.h
index b64fc08a47a..2bf874d3a85 100644
--- a/source/blender/makesdna/DNA_gpencil_types.h
+++ b/source/blender/makesdna/DNA_gpencil_types.h
@@ -147,14 +147,14 @@ typedef struct bGPdata {
// XXX many of these flags should be deprecated for more general ideas in 2.5
/* don't allow painting to occur at all */
// XXX is deprecated - not well understood
-#define GP_DATA_LMBPLOCK (1<<0)
+// #define GP_DATA_LMBPLOCK (1<<0)
/* show debugging info in viewport (i.e. status print) */
#define GP_DATA_DISPINFO (1<<1)
/* in Action Editor, show as expanded channel */
#define GP_DATA_EXPAND (1<<2)
/* is the block overriding all clicks? */
// XXX is deprecated - nasty old concept
-#define GP_DATA_EDITPAINT (1<<3)
+// #define GP_DATA_EDITPAINT (1<<3)
/* new strokes are added in viewport space */
#define GP_DATA_VIEWALIGN (1<<4)
/* Project into the screens Z values */
diff --git a/source/blender/makesdna/DNA_image_types.h b/source/blender/makesdna/DNA_image_types.h
index dae520f458d..6b0299e6d50 100644
--- a/source/blender/makesdna/DNA_image_types.h
+++ b/source/blender/makesdna/DNA_image_types.h
@@ -32,6 +32,7 @@
#ifndef __DNA_IMAGE_TYPES_H__
#define __DNA_IMAGE_TYPES_H__
+#include "DNA_defs.h"
#include "DNA_ID.h"
#include "DNA_color_types.h" /* for color management */
@@ -122,18 +123,24 @@ typedef struct Image {
/* **************** IMAGE ********************* */
/* Image.flag */
-#define IMA_FIELDS 1
-#define IMA_STD_FIELD 2
-#define IMA_DO_PREMUL 4 /* deprecated, should not be used */
-#define IMA_REFLECT 16
-#define IMA_NOCOLLECT 32
-// #define IMA_DONE_TAG 64 // UNUSED
-#define IMA_OLD_PREMUL 128
-/*#define IMA_CM_PREDIVIDE 256*/ /* deprecated, should not be used */
-#define IMA_USED_FOR_RENDER 512
-#define IMA_USER_FRAME_IN_RANGE 1024 /* for image user, but these flags are mixed */
-#define IMA_VIEW_AS_RENDER 2048
-#define IMA_IGNORE_ALPHA 4096
+enum {
+ IMA_FIELDS = (1 << 0),
+ IMA_STD_FIELD = (1 << 1),
+ IMA_DO_PREMUL = (1 << 2), /* deprecated, should not be used */
+ IMA_REFLECT = (1 << 4),
+ IMA_NOCOLLECT = (1 << 5),
+ //IMA_DONE_TAG = (1 << 6), // UNUSED
+ IMA_OLD_PREMUL = (1 << 7),
+ // IMA_CM_PREDIVIDE = (1 << 8), /* deprecated, should not be used */
+ IMA_USED_FOR_RENDER = (1 << 9),
+ IMA_USER_FRAME_IN_RANGE = (1 << 10), /* for image user, but these flags are mixed */
+ IMA_VIEW_AS_RENDER = (1 << 11),
+ IMA_IGNORE_ALPHA = (1 << 12),
+};
+
+#if (DNA_DEPRECATED_GCC_POISON == 1)
+#pragma GCC poison IMA_DO_PREMUL
+#endif
/* Image.tpageflag */
#define IMA_TILES 1
diff --git a/source/blender/makesdna/DNA_lamp_types.h b/source/blender/makesdna/DNA_lamp_types.h
index a1b3d4265d3..b7aae005e3b 100644
--- a/source/blender/makesdna/DNA_lamp_types.h
+++ b/source/blender/makesdna/DNA_lamp_types.h
@@ -65,8 +65,8 @@ typedef struct Lamp {
short falloff_type;
short pad2;
- float clipsta, clipend, shadspotsize;
- float bias, soft, compressthresh, bleedbias, pad5[2];
+ float clipsta, clipend;
+ float bias, soft, compressthresh, bleedbias, pad5;
short bufsize, samp, buffers, filtertype;
char bufflag, buftype;
diff --git a/source/blender/makesdna/DNA_mesh_types.h b/source/blender/makesdna/DNA_mesh_types.h
index 7cdb79232a9..b942197e52c 100644
--- a/source/blender/makesdna/DNA_mesh_types.h
+++ b/source/blender/makesdna/DNA_mesh_types.h
@@ -140,6 +140,10 @@ typedef struct TFace {
short mode, tile, unwrap;
} TFace;
+#if (DNA_DEPRECATED_GCC_POISON == 1)
+#pragma GCC poison TFace
+#endif
+
/* **************** MESH ********************* */
/* texflag */
@@ -164,7 +168,7 @@ typedef struct TFace {
/* me->flag */
/* #define ME_ISDONE 1 */
-#define ME_DEPRECATED 2
+/* #define ME_DEPRECATED 2 */
#define ME_TWOSIDED 4
#define ME_UVEFFECT 8
#define ME_VCOLEFFECT 16
diff --git a/source/blender/makesdna/DNA_meshdata_types.h b/source/blender/makesdna/DNA_meshdata_types.h
index 1114549f2da..c370e677df0 100644
--- a/source/blender/makesdna/DNA_meshdata_types.h
+++ b/source/blender/makesdna/DNA_meshdata_types.h
@@ -358,8 +358,8 @@ enum {
/* mtface->flag */
enum {
- TF_SELECT = (1 << 0), /* use MFace hide flag (after 2.43), should be able to reuse after 2.44 */
- TF_ACTIVE = (1 << 1), /* deprecated! */
+ // TF_SELECT = (1 << 0), /* use MFace hide flag (after 2.43), should be able to reuse after 2.44 */
+ // TF_ACTIVE = (1 << 1), /* deprecated! */
TF_SEL1 = (1 << 2),
TF_SEL2 = (1 << 3),
TF_SEL3 = (1 << 4),
@@ -377,7 +377,7 @@ enum {
TF_CONVERTED = (1 << 5), /* tface converted to material */
TF_SHAREDCOL = (1 << 6),
- TF_TILES = (1 << 7), /* deprecated */
+ // TF_TILES = (1 << 7), /* deprecated */
TF_BILLBOARD = (1 << 8),
TF_TWOSIDE = (1 << 9),
TF_INVISIBLE = (1 << 10),
diff --git a/source/blender/makesdna/DNA_modifier_types.h b/source/blender/makesdna/DNA_modifier_types.h
index 59ce965b582..2f89a83d42d 100644
--- a/source/blender/makesdna/DNA_modifier_types.h
+++ b/source/blender/makesdna/DNA_modifier_types.h
@@ -819,16 +819,21 @@ enum {
MOD_SOLIDIFY_FLIP = (1 << 5),
};
+#if (DNA_DEPRECATED_GCC_POISON == 1)
+#pragma GCC poison MOD_SOLIDIFY_RIM_MATERIAL
+#endif
+
typedef struct ScrewModifierData {
ModifierData modifier;
struct Object *ob_axis;
- int steps;
- int render_steps;
- int iter;
+ unsigned int steps;
+ unsigned int render_steps;
+ unsigned int iter;
float screw_ofs;
float angle;
- short axis;
+ char axis;
+ char pad;
short flag;
} ScrewModifierData;
@@ -838,6 +843,8 @@ enum {
MOD_SCREW_OBJECT_OFFSET = (1 << 2),
/* MOD_SCREW_OBJECT_ANGLE = (1 << 4), */
MOD_SCREW_SMOOTH_SHADING = (1 << 5),
+ MOD_SCREW_UV_STRETCH_U = (1 << 6),
+ MOD_SCREW_UV_STRETCH_V = (1 << 7),
};
typedef struct OceanModifierData {
@@ -1187,6 +1194,10 @@ enum {
MOD_TRIANGULATE_BEAUTY = (1 << 0), /* deprecated */
};
+#if (DNA_DEPRECATED_GCC_POISON == 1)
+#pragma GCC poison MOD_TRIANGULATE_BEAUTY
+#endif
+
/* Triangulate methods - NGons */
enum {
MOD_TRIANGULATE_NGON_BEAUTY = 0,
@@ -1310,4 +1321,20 @@ enum {
};
+typedef struct LaplacianDeformModifierData {
+ ModifierData modifier;
+ char anchor_grp_name[64]; /* MAX_VGROUP_NAME */
+ int total_verts, repeat;
+ float *vertexco;
+ void *cache_system; /* runtime only */
+ short flag, pad[3];
+
+} LaplacianDeformModifierData;
+
+/* Smooth modifier flags */
+enum {
+ MOD_LAPLACIANDEFORM_BIND = 1,
+};
+
+
#endif /* __DNA_MODIFIER_TYPES_H__ */
diff --git a/source/blender/makesdna/DNA_node_types.h b/source/blender/makesdna/DNA_node_types.h
index a4510dd23fd..4f7c49a0ca3 100644
--- a/source/blender/makesdna/DNA_node_types.h
+++ b/source/blender/makesdna/DNA_node_types.h
@@ -153,8 +153,8 @@ typedef enum eNodeSocketFlag {
SOCK_HIDDEN = 2, /* hidden is user defined, to hide unused */
SOCK_IN_USE = 4, /* for quick check if socket is linked */
SOCK_UNAVAIL = 8, /* unavailable is for dynamic sockets */
- __SOCK_DYNAMIC = 16, /* DEPRECATED dynamic socket (can be modified by user) */
- __SOCK_INTERNAL = 32, /* DEPRECATED group socket should not be exposed */
+ // SOCK_DYNAMIC = 16, /* DEPRECATED dynamic socket (can be modified by user) */
+ // SOCK_INTERNAL = 32, /* DEPRECATED group socket should not be exposed */
SOCK_COLLAPSED = 64, /* socket collapsed in UI */
SOCK_HIDE_VALUE = 128, /* hide socket value, if it gets auto default */
SOCK_AUTO_HIDDEN__DEPRECATED = 256 /* socket hidden automatically, to distinguish from manually hidden */
@@ -227,7 +227,7 @@ typedef struct bNode {
#define NODE_TEST 256
/* node is disabled */
#define NODE_MUTED 512
-#define NODE_CUSTOM_NAME 1024 /* deprecated! */
+// #define NODE_CUSTOM_NAME 1024 /* deprecated! */
/* group node types: use const outputs by default */
#define NODE_CONST_OUTPUT (1<<11)
/* node is always behind others */
@@ -966,9 +966,15 @@ typedef struct NodeShaderNormalMap {
#define SHD_NORMAL_MAP_BLENDER_WORLD 4
/* subsurface */
-#define SHD_SUBSURFACE_COMPATIBLE 0 // Deprecated
-#define SHD_SUBSURFACE_CUBIC 1
-#define SHD_SUBSURFACE_GAUSSIAN 2
+enum {
+ SHD_SUBSURFACE_COMPATIBLE = 0, // Deprecated
+ SHD_SUBSURFACE_CUBIC = 1,
+ SHD_SUBSURFACE_GAUSSIAN = 2,
+};
+
+#if (DNA_DEPRECATED_GCC_POISON == 1)
+#pragma GCC poison SHD_SUBSURFACE_COMPATIBLE
+#endif
/* blur node */
#define CMP_NODE_BLUR_ASPECT_NONE 0
diff --git a/source/blender/makesdna/DNA_object_types.h b/source/blender/makesdna/DNA_object_types.h
index 2ff697f513f..9d07e046096 100644
--- a/source/blender/makesdna/DNA_object_types.h
+++ b/source/blender/makesdna/DNA_object_types.h
@@ -542,6 +542,8 @@ enum {
OB_NAVMESH = 1 << 20,
OB_HASOBSTACLE = 1 << 21,
OB_CHARACTER = 1 << 22,
+
+ OB_RECORD_ANIMATION = 1 << 23,
};
/* ob->gameflag2 */
@@ -607,7 +609,7 @@ enum {
/* ob->shapeflag */
enum {
OB_SHAPE_LOCK = 1 << 0,
- OB_SHAPE_TEMPLOCK = 1 << 1, /* deprecated */
+ // OB_SHAPE_TEMPLOCK = 1 << 1, /* deprecated */
OB_SHAPE_EDIT_MODE = 1 << 2,
};
diff --git a/source/blender/makesdna/DNA_particle_types.h b/source/blender/makesdna/DNA_particle_types.h
index b7ca3066b4f..4f4be3965ff 100644
--- a/source/blender/makesdna/DNA_particle_types.h
+++ b/source/blender/makesdna/DNA_particle_types.h
@@ -509,7 +509,7 @@ typedef struct ParticleSystem {
#define PSYS_GLOBAL_HAIR 2
#define PSYS_HAIR_DYNAMICS 4
#define PSYS_KEYED_TIMING 8
-#define PSYS_ENABLED 16 /* deprecated */
+//#define PSYS_ENABLED 16 /* deprecated */
#define PSYS_HAIR_UPDATED 32 /* signal for updating hair particle mode */
#define PSYS_DRAWING 64
#define PSYS_USE_IMAT 128
diff --git a/source/blender/makesdna/DNA_screen_types.h b/source/blender/makesdna/DNA_screen_types.h
index ec86a4739c5..6b90557113a 100644
--- a/source/blender/makesdna/DNA_screen_types.h
+++ b/source/blender/makesdna/DNA_screen_types.h
@@ -172,7 +172,7 @@ typedef struct ScrArea {
short flag;
short region_active_win; /* index of last used region of 'RGN_TYPE_WINDOW'
* runtuime variable, updated by executing operators */
- short pad;
+ char temp, pad;
struct SpaceType *type; /* callbacks for this space type */
diff --git a/source/blender/makesdna/DNA_sequence_types.h b/source/blender/makesdna/DNA_sequence_types.h
index 5dbc80c16a5..69d4693ab05 100644
--- a/source/blender/makesdna/DNA_sequence_types.h
+++ b/source/blender/makesdna/DNA_sequence_types.h
@@ -325,37 +325,43 @@ typedef struct SequencerScopes {
#define SEQ_NAME_MAXSTR 64
/* seq->flag */
-#define SEQ_LEFTSEL (1 << 1)
-#define SEQ_RIGHTSEL (1 << 2)
-#define SEQ_OVERLAP (1 << 3)
-#define SEQ_FILTERY (1 << 4)
-#define SEQ_MUTE (1 << 5)
-#define SEQ_MAKE_PREMUL (1 << 6) /* deprecated, used for compatibility code only */
-#define SEQ_REVERSE_FRAMES (1 << 7)
-#define SEQ_IPO_FRAME_LOCKED (1 << 8)
-#define SEQ_EFFECT_NOT_LOADED (1 << 9)
-#define SEQ_FLAG_DELETE (1 << 10)
-#define SEQ_FLIPX (1 << 11)
-#define SEQ_FLIPY (1 << 12)
-#define SEQ_MAKE_FLOAT (1 << 13)
-#define SEQ_LOCK (1 << 14)
-#define SEQ_USE_PROXY (1 << 15)
-#define SEQ_USE_TRANSFORM (1 << 16)
-#define SEQ_USE_CROP (1 << 17)
-/* #define SEQ_USE_COLOR_BALANCE (1 << 18) */ /* DEPRECATED */
-#define SEQ_USE_PROXY_CUSTOM_DIR (1 << 19)
-
-#define SEQ_USE_PROXY_CUSTOM_FILE (1 << 21)
-#define SEQ_USE_EFFECT_DEFAULT_FADE (1 << 22)
-#define SEQ_USE_LINEAR_MODIFIERS (1 << 23)
-
-// flags for whether those properties are animated or not
-#define SEQ_AUDIO_VOLUME_ANIMATED (1 << 24)
-#define SEQ_AUDIO_PITCH_ANIMATED (1 << 25)
-#define SEQ_AUDIO_PAN_ANIMATED (1 << 26)
-#define SEQ_AUDIO_DRAW_WAVEFORM (1 << 27)
-
-#define SEQ_INVALID_EFFECT (1 << 31)
+enum {
+ SEQ_LEFTSEL = (1 << 1),
+ SEQ_RIGHTSEL = (1 << 2),
+ SEQ_OVERLAP = (1 << 3),
+ SEQ_FILTERY = (1 << 4),
+ SEQ_MUTE = (1 << 5),
+ SEQ_MAKE_PREMUL = (1 << 6), /* deprecated, used for compatibility code only */
+ SEQ_REVERSE_FRAMES = (1 << 7),
+ SEQ_IPO_FRAME_LOCKED = (1 << 8),
+ SEQ_EFFECT_NOT_LOADED = (1 << 9),
+ SEQ_FLAG_DELETE = (1 << 10),
+ SEQ_FLIPX = (1 << 11),
+ SEQ_FLIPY = (1 << 12),
+ SEQ_MAKE_FLOAT = (1 << 13),
+ SEQ_LOCK = (1 << 14),
+ SEQ_USE_PROXY = (1 << 15),
+ SEQ_USE_TRANSFORM = (1 << 16),
+ SEQ_USE_CROP = (1 << 17),
+ /* SEQ_USE_COLOR_BALANCE = (1 << 18), */ /* DEPRECATED */
+ SEQ_USE_PROXY_CUSTOM_DIR = (1 << 19),
+
+ SEQ_USE_PROXY_CUSTOM_FILE = (1 << 21),
+ SEQ_USE_EFFECT_DEFAULT_FADE = (1 << 22),
+ SEQ_USE_LINEAR_MODIFIERS = (1 << 23),
+
+ /* flags for whether those properties are animated or not */
+ SEQ_AUDIO_VOLUME_ANIMATED = (1 << 24),
+ SEQ_AUDIO_PITCH_ANIMATED = (1 << 25),
+ SEQ_AUDIO_PAN_ANIMATED = (1 << 26),
+ SEQ_AUDIO_DRAW_WAVEFORM = (1 << 27),
+
+ SEQ_INVALID_EFFECT = (1 << 31),
+};
+
+#if (DNA_DEPRECATED_GCC_POISON == 1)
+#pragma GCC poison SEQ_MAKE_PREMUL
+#endif
/* convenience define for all selection flags */
#define SEQ_ALLSEL (SELECT + SEQ_LEFTSEL + SEQ_RIGHTSEL)
diff --git a/source/blender/makesdna/DNA_smoke_types.h b/source/blender/makesdna/DNA_smoke_types.h
index d01eceb44f0..25c98b4f07e 100644
--- a/source/blender/makesdna/DNA_smoke_types.h
+++ b/source/blender/makesdna/DNA_smoke_types.h
@@ -33,13 +33,19 @@
#define __DNA_SMOKE_TYPES_H__
/* flags */
-#define MOD_SMOKE_HIGHRES (1<<1) /* enable high resolution */
-#define MOD_SMOKE_DISSOLVE (1<<2) /* let smoke dissolve */
-#define MOD_SMOKE_DISSOLVE_LOG (1<<3) /* using 1/x for dissolve */
-
-#define MOD_SMOKE_HIGH_SMOOTH (1<<5) /* -- Deprecated -- */
-#define MOD_SMOKE_FILE_LOAD (1<<6) /* flag for file load */
-#define MOD_SMOKE_ADAPTIVE_DOMAIN (1<<7)
+enum {
+ MOD_SMOKE_HIGHRES = (1 << 1), /* enable high resolution */
+ MOD_SMOKE_DISSOLVE = (1 << 2), /* let smoke dissolve */
+ MOD_SMOKE_DISSOLVE_LOG = (1 << 3), /* using 1/x for dissolve */
+
+ MOD_SMOKE_HIGH_SMOOTH = (1 << 5), /* -- Deprecated -- */
+ MOD_SMOKE_FILE_LOAD = (1 << 6), /* flag for file load */
+ MOD_SMOKE_ADAPTIVE_DOMAIN = (1 << 7),
+};
+
+#if (DNA_DEPRECATED_GCC_POISON == 1)
+#pragma GCC poison MOD_SMOKE_HIGH_SMOOTH
+#endif
/* noise */
#define MOD_SMOKE_NOISEWAVE (1<<0)
diff --git a/source/blender/makesdna/DNA_sound_types.h b/source/blender/makesdna/DNA_sound_types.h
index 040942d6cea..d7a51359777 100644
--- a/source/blender/makesdna/DNA_sound_types.h
+++ b/source/blender/makesdna/DNA_sound_types.h
@@ -33,6 +33,7 @@
#ifndef __DNA_SOUND_TYPES_H__
#define __DNA_SOUND_TYPES_H__
+#include "DNA_defs.h"
#include "DNA_ID.h"
/* stupid... could easily be solved */
@@ -109,14 +110,21 @@ typedef enum eSound_Type {
#endif
/* spacesound->flag */
-#define SND_DRAWFRAMES 1
-#define SND_CFRA_NUM 2
-
-#define SOUND_FLAGS_3D (1 << 3) /* deprecated! used for sound actuator loading */
-#define SOUND_FLAGS_CACHING (1 << 4)
-#define SOUND_FLAGS_MONO (1 << 5)
+enum {
+ SND_DRAWFRAMES = 1,
+ SND_CFRA_NUM = 2,
+};
+
+enum {
+ SOUND_FLAGS_3D = (1 << 3), /* deprecated! used for sound actuator loading */
+ SOUND_FLAGS_CACHING = (1 << 4),
+ SOUND_FLAGS_MONO = (1 << 5),
+};
+
+#if (DNA_DEPRECATED_GCC_POISON == 1)
+#pragma GCC poison SOUND_FLAGS_3D
+#endif
/* to DNA_sound_types.h*/
#endif
-
diff --git a/source/blender/makesdna/DNA_space_types.h b/source/blender/makesdna/DNA_space_types.h
index 4ebfe349a9f..4fe0920b7c6 100644
--- a/source/blender/makesdna/DNA_space_types.h
+++ b/source/blender/makesdna/DNA_space_types.h
@@ -455,10 +455,10 @@ typedef enum eScreen_Redraws_Flag {
TIME_ALL_3D_WIN = (1 << 1),
TIME_ALL_ANIM_WIN = (1 << 2),
TIME_ALL_BUTS_WIN = (1 << 3),
- TIME_WITH_SEQ_AUDIO = (1 << 4), /* DEPRECATED */
+ // TIME_WITH_SEQ_AUDIO = (1 << 4), /* DEPRECATED */
TIME_SEQ = (1 << 5),
TIME_ALL_IMAGE_WIN = (1 << 6),
- TIME_CONTINUE_PHYSICS = (1 << 7), /* UNUSED */
+ // TIME_CONTINUE_PHYSICS = (1 << 7), /* UNUSED */
TIME_NODES = (1 << 8),
TIME_CLIPS = (1 << 9),
} eScreen_Redraws_Flag;
@@ -969,7 +969,7 @@ typedef enum eSpaceNode_Flag {
SNODE_SHOW_B = (1 << 9),
SNODE_AUTO_RENDER = (1 << 5),
SNODE_SHOW_HIGHLIGHT = (1 << 6),
- SNODE_USE_HIDDEN_PREVIEW = (1 << 10),
+// SNODE_USE_HIDDEN_PREVIEW = (1 << 10), DNA_DEPRECATED December2013
SNODE_NEW_SHADERS = (1 << 11),
SNODE_PIN = (1 << 12),
} eSpaceNode_Flag;
@@ -1179,6 +1179,11 @@ typedef enum eSpace_Type {
SPACEICONMAX = SPACE_CLIP
} eSpace_Type;
+// TODO: SPACE_SCRIPT
+#if (DNA_DEPRECATED_GCC_POISON == 1)
+#pragma GCC poison SPACE_IMASEL SPACE_SOUND
+#endif
+
#define IMG_SIZE_FALLBACK 256
#endif /* __DNA_SPACE_TYPES_H__ */
diff --git a/source/blender/makesdna/DNA_tracking_types.h b/source/blender/makesdna/DNA_tracking_types.h
index ad9a2ea169c..4e6a762c36a 100644
--- a/source/blender/makesdna/DNA_tracking_types.h
+++ b/source/blender/makesdna/DNA_tracking_types.h
@@ -44,6 +44,7 @@
struct bGPdata;
struct ImBuf;
+struct Image;
struct MovieReconstructedCamera;
struct MovieTrackingCamera;
struct MovieTrackingBundle;
@@ -189,8 +190,11 @@ typedef struct MovieTrackingPlaneTrack {
int flag; /* flags (selection, ...) */
+ struct Image *image; /* Image displaying during editing */
+ float image_opacity; /* Opacity of the image */
+
/* Runtime data */
- int last_marker, pad2; /* Most recently used marker */
+ int last_marker; /* Most recently used marker */
} MovieTrackingPlaneTrack;
typedef struct MovieTrackingSettings {
diff --git a/source/blender/makesdna/DNA_userdef_types.h b/source/blender/makesdna/DNA_userdef_types.h
index 37d5f313dfb..6aab0a0a0d1 100644
--- a/source/blender/makesdna/DNA_userdef_types.h
+++ b/source/blender/makesdna/DNA_userdef_types.h
@@ -257,10 +257,15 @@ typedef struct ThemeSpace {
char noodle_curving;
/* syntax for textwindow and nodes */
- char syntaxl[4], syntaxs[4];
- char syntaxb[4], syntaxn[4];
- char syntaxv[4], syntaxc[4];
- char syntaxd[4], syntaxr[4];
+ char syntaxl[4], syntaxs[4]; // in nodespace used for backdrop matte
+ char syntaxb[4], syntaxn[4]; // in nodespace used for color input
+ char syntaxv[4], syntaxc[4]; // in nodespace used for converter group
+ char syntaxd[4], syntaxr[4]; // in nodespace used for distort
+
+ char nodeclass_output[4], nodeclass_filter[4];
+ char nodeclass_vector[4], nodeclass_texture[4];
+ char nodeclass_shader[4], nodeclass_script[4];
+ char nodeclass_pattern[4], nodeclass_layout[4];
char movie[4], movieclip[4], mask[4], image[4], scene[4], audio[4]; /* for sequence editor */
char effect[4], transition[4], meta[4];
@@ -286,8 +291,8 @@ typedef struct ThemeSpace {
char preview_stitch_unstitchable[4];
char preview_stitch_active[4];
- char uv_shadow[4];
- char uv_others[4];
+ char uv_shadow[4]; /* two uses, for uvs with modifier applied on mesh and uvs during painting */
+ char uv_others[4]; /* uvs of other objects */
char match[4]; /* outliner - filter match */
char selected_highlight[4]; /* outliner - selected item */
@@ -374,6 +379,17 @@ typedef struct SolidLight {
float col[4], spec[4], vec[4];
} SolidLight;
+typedef struct WalkNavigation {
+ float mouse_speed; /* speed factor for look around */
+ float walk_speed;
+ float walk_speed_factor;
+ float view_height;
+ float jump_height;
+ float teleport_time; /* duration to use for teleporting */
+ short flag;
+ short pad[3];
+} WalkNavigation;
+
typedef struct UserDef {
/* UserDef has separate do-version handling, and can be read from other files */
int versionfile, subversionfile;
@@ -477,7 +493,7 @@ typedef struct UserDef {
float gpencil_new_layer_col[4]; /* default color for newly created Grease Pencil layers */
short tweak_threshold;
- short pad3;
+ char navigation_mode, pad;
char author[80]; /* author name for file formats supporting it */
@@ -486,6 +502,8 @@ typedef struct UserDef {
float fcu_inactive_alpha; /* opacity of inactive F-Curves in F-Curve Editor */
float pixelsize; /* private, set by GHOST, to multiply DPI with */
+
+ struct WalkNavigation walk_navigation;
} UserDef;
extern UserDef U; /* from blenkernel blender.c */
@@ -552,6 +570,18 @@ typedef enum eViewZoom_Style {
USER_ZOOM_DOLLY = 2
} eViewZoom_Style;
+/* navigation_mode */
+typedef enum eViewNavigation_Method {
+ VIEW_NAVIGATION_WALK = 0,
+ VIEW_NAVIGATION_FLY = 1,
+} eViewNavigation_Method;
+
+/* flag */
+typedef enum eWalkNavigation_Flag {
+ USER_WALK_GRAVITY = (1 << 0),
+ USER_WALK_MOUSE_REVERSE = (1 << 1),
+} eWalkNavigation_Flag;
+
/* uiflag */
typedef enum eUserpref_UI_Flag {
/* flags 0 and 1 were old flags (for autokeying) that aren't used anymore */
diff --git a/source/blender/makesdna/DNA_view3d_types.h b/source/blender/makesdna/DNA_view3d_types.h
index c724340f5ea..a154f6fed15 100644
--- a/source/blender/makesdna/DNA_view3d_types.h
+++ b/source/blender/makesdna/DNA_view3d_types.h
@@ -266,6 +266,9 @@ typedef struct View3D {
#define RV3D_VIEW_PERSPORTHO 7
#define RV3D_VIEW_CAMERA 8
+#define RV3D_VIEW_IS_AXIS(view) \
+ ((view >= RV3D_VIEW_FRONT) && (view <= RV3D_VIEW_BOTTOM))
+
/* View3d->flag2 (short) */
#define V3D_RENDER_OVERRIDE 4
#define V3D_SOLID_TEX 8
diff --git a/source/blender/makesdna/DNA_world_types.h b/source/blender/makesdna/DNA_world_types.h
index 3e01e159d6c..50542797f0b 100644
--- a/source/blender/makesdna/DNA_world_types.h
+++ b/source/blender/makesdna/DNA_world_types.h
@@ -142,7 +142,7 @@ typedef struct World {
/* mode */
#define WO_MIST 1
-#define WO_STARS 2 /* deprecated */
+//#define WO_STARS 2 /* deprecated */
/*#define WO_DOF 4*/
#define WO_ACTIVITY_CULLING 8
#define WO_ENV_LIGHT 16
@@ -151,10 +151,16 @@ typedef struct World {
#define WO_INDIRECT_LIGHT 128
/* aomix */
-#define WO_AOADD 0
-#define WO_AOSUB 1 /* deprecated */
-#define WO_AOADDSUB 2 /* deprecated */
-#define WO_AOMUL 3
+enum {
+ WO_AOADD = 0,
+ WO_AOSUB = 1, /* deprecated */
+ WO_AOADDSUB = 2, /* deprecated */
+ WO_AOMUL = 3,
+};
+
+#if (DNA_DEPRECATED_GCC_POISON == 1)
+#pragma GCC poison WO_AOSUB WO_AOADDSUB
+#endif
/* ao_samp_method - methods for sampling the AO hemi */
#define WO_AOSAMP_CONSTANT 0
diff --git a/source/blender/makesdna/intern/makesdna.c b/source/blender/makesdna/intern/makesdna.c
index 2665da1b435..aac79245501 100644
--- a/source/blender/makesdna/intern/makesdna.c
+++ b/source/blender/makesdna/intern/makesdna.c
@@ -1209,6 +1209,14 @@ int main(int argc, char **argv)
#endif /* if 0 */
+/* even though DNA supports, 'long' shouldn't be used since it can be either 32 or 64bit,
+ * use int or int64_t instead.
+ * Only valid use would be as a runtime variable if an API expected a long,
+ * but so far we dont have this happening. */
+#ifdef __GNUC__
+# pragma GCC poison long
+#endif
+
#include "DNA_listBase.h"
#include "DNA_vec_types.h"
#include "DNA_ID.h"
diff --git a/source/blender/makesdna/DNA_scene_types.h b/source/blender/makesdna/DNA_scene_types.h
index 7aabad86809..86145de3291 100644
--- a/source/blender/makesdna/DNA_scene_types.h
+++ b/source/blender/makesdna/DNA_scene_types.h
@@ -196,7 +196,7 @@ typedef struct SceneRenderLayer {
#define SCE_LAY_SOLID 1
#define SCE_LAY_ZTRA 2
#define SCE_LAY_HALO 4
-#define SCE_LAY_EDGE 8 /* deprecated */
+// #define SCE_LAY_EDGE 8 /* deprecated */
#define SCE_LAY_SKY 16
#define SCE_LAY_STRAND 32
#define SCE_LAY_FRS 64
@@ -725,9 +725,15 @@ typedef struct GameData {
#define GAME_PLAYER_DESKTOP_RESOLUTION (1 << 1)
/* GameData.matmode */
-#define GAME_MAT_TEXFACE 0 /* deprecated */
-#define GAME_MAT_MULTITEX 1
-#define GAME_MAT_GLSL 2
+enum {
+ GAME_MAT_TEXFACE = 0, /* deprecated */
+ GAME_MAT_MULTITEX = 1,
+ GAME_MAT_GLSL = 2,
+};
+
+#if (DNA_DEPRECATED_GCC_POISON == 1)
+#pragma GCC poison GAME_MAT_TEXFACE
+#endif
/* UV Paint */
#define UV_SCULPT_LOCK_BORDERS 1
@@ -770,7 +776,8 @@ typedef struct Paint {
* smooth the stroke */
int num_input_samples;
- int pad;
+ /* flags used for symmetry */
+ int symmetry_flags;
} Paint;
/* ------------------------------------------- */
@@ -919,8 +926,10 @@ typedef struct UnifiedPaintSettings {
int anchored_size;
float anchored_initial_mouse[2];
+ /* check is there an ongoing stroke right now */
+ int stroke_active;
+
/* drawing pressure */
- int draw_pressure;
float pressure_value;
/* position of mouse, used to sample the texture */
@@ -1220,7 +1229,7 @@ typedef struct Scene {
#define R_GAMMA 0x0004
#define R_ORTHO 0x0008
#define R_ENVMAP 0x0010
-#define R_EDGE 0x0020 /* deprecated */
+/*#define R_EDGE 0x0020 deprecated */
#define R_FIELDS 0x0040
#define R_FIELDSTILL 0x0080
/*#define R_RADIO 0x0100 */ /* deprecated */
@@ -1330,21 +1339,36 @@ typedef struct Scene {
/*#define R_ALPHAKEY 2*/ /* deprecated, shouldn't be used */
/* color_mgt_flag */
-#define R_COLOR_MANAGEMENT (1 << 0) /* deprecated, should only be used in versioning code only */
-/*#define R_COLOR_MANAGEMENT_PREDIVIDE (1 << 1)*/ /* deprecated, shouldn't be used */
+enum {
+ R_COLOR_MANAGEMENT = (1 << 0), /* deprecated, should only be used in versioning code only */
+ /*R_COLOR_MANAGEMENT_PREDIVIDE = (1 << 1)*/ /* deprecated, shouldn't be used */
+};
+
+#if 0 /* TODO */
+#if (DNA_DEPRECATED_GCC_POISON == 1)
+#pragma GCC poison R_COLOR_MANAGEMENT
+#endif
+#endif
/* subimtype, flag options for imtype */
-#define R_OPENEXR_HALF 1 /*deprecated*/
-#define R_OPENEXR_ZBUF 2 /*deprecated*/
-#define R_PREVIEW_JPG 4 /*deprecated*/
-#define R_CINEON_LOG 8 /*deprecated*/
-#define R_TIFF_16BIT 16 /*deprecated*/
-
-#define R_JPEG2K_12BIT 32 /* Jpeg2000 */ /*deprecated*/
-#define R_JPEG2K_16BIT 64 /*deprecated*/
-#define R_JPEG2K_YCC 128 /* when disabled use RGB */ /*deprecated*/
-#define R_JPEG2K_CINE_PRESET 256 /*deprecated*/
-#define R_JPEG2K_CINE_48FPS 512 /*deprecated*/
+enum {
+ R_OPENEXR_HALF = 1, /*deprecated*/
+ R_OPENEXR_ZBUF = 2, /*deprecated*/
+ R_PREVIEW_JPG = 4, /*deprecated*/
+ R_CINEON_LOG = 8, /*deprecated*/
+ R_TIFF_16BIT = 16, /*deprecated*/
+
+ R_JPEG2K_12BIT = 32, /* Jpeg2000 */ /*deprecated*/
+ R_JPEG2K_16BIT = 64, /*deprecated*/
+ R_JPEG2K_YCC = 128, /* when disabled use RGB */ /*deprecated*/
+ R_JPEG2K_CINE_PRESET = 256, /*deprecated*/
+ R_JPEG2K_CINE_48FPS = 512, /*deprecated*/
+};
+
+#if (DNA_DEPRECATED_GCC_POISON == 1)
+#pragma GCC poison R_OPENEXR_HALF R_OPENEXR_ZBUF R_PREVIEW_JPG R_CINEON_LOG R_TIFF_16BIT
+#pragma GCC poison R_JPEG2K_12BIT R_JPEG2K_16BIT R_JPEG2K_YCC R_JPEG2K_CINE_PRESET R_JPEG2K_CINE_48FPS
+#endif
/* bake_mode: same as RE_BAKE_xxx defines */
/* bake_flag: */
@@ -1539,9 +1563,16 @@ typedef enum eVGroupSelect {
#define AUDIO_SCRUB (1<<2)
#define AUDIO_VOLUME_ANIMATED (1<<3)
-#define FFMPEG_MULTIPLEX_AUDIO 1 /* deprecated, you can choose none as audiocodec now */
-#define FFMPEG_AUTOSPLIT_OUTPUT 2
-#define FFMPEG_LOSSLESS_OUTPUT 4
+enum {
+ FFMPEG_MULTIPLEX_AUDIO = 1, /* deprecated, you can choose none as audiocodec now */
+ FFMPEG_AUTOSPLIT_OUTPUT = 2,
+ FFMPEG_LOSSLESS_OUTPUT = 4,
+};
+
+#if (DNA_DEPRECATED_GCC_POISON == 1)
+#pragma GCC poison FFMPEG_MULTIPLEX_AUDIO
+#endif
+
/* Paint.flags */
typedef enum {
@@ -1550,16 +1581,31 @@ typedef enum {
PAINT_SHOW_BRUSH_ON_SURFACE = (1 << 2),
} PaintFlags;
+/* Paint.symmetry_flags
+ * (for now just a duplicate of sculpt symmetry flags) */
+typedef enum SymmetryFlags {
+ PAINT_SYMM_X = (1 << 0),
+ PAINT_SYMM_Y = (1 << 1),
+ PAINT_SYMM_Z = (1 << 2),
+ PAINT_SYMMETRY_FEATHER = (1 << 3)
+} SymmetryFlags;
+
+#define PAINT_SYMM_AXIS_ALL (PAINT_SYMM_X | PAINT_SYMM_Y | PAINT_SYMM_Z)
+
/* Sculpt.flags */
/* These can eventually be moved to paint flags? */
typedef enum SculptFlags {
+ /* deprecated, part of paint struct symmetry_flags now */
SCULPT_SYMM_X = (1 << 0),
SCULPT_SYMM_Y = (1 << 1),
SCULPT_SYMM_Z = (1 << 2),
+
SCULPT_LOCK_X = (1 << 3),
SCULPT_LOCK_Y = (1 << 4),
SCULPT_LOCK_Z = (1 << 5),
+ /* deprecated, part of paint struct symmetry_flags now */
SCULPT_SYMMETRY_FEATHER = (1 << 6),
+
SCULPT_USE_OPENMP = (1 << 7),
SCULPT_ONLY_DEFORM = (1 << 8),
SCULPT_SHOW_DIFFUSE = (1 << 9),
@@ -1568,11 +1614,17 @@ typedef enum SculptFlags {
* dynamic-topology mode */
SCULPT_DYNTOPO_SMOOTH_SHADING = (1 << 10),
- /* If set, dynamic-topology brushes will collapse short edges in
- * addition to subdividing long ones */
+ /* If set, dynamic-topology brushes will subdivide short edges */
+ SCULPT_DYNTOPO_SUBDIVIDE = (1 << 12),
+ /* If set, dynamic-topology brushes will collapse short edges */
SCULPT_DYNTOPO_COLLAPSE = (1 << 11)
} SculptFlags;
+#if (DNA_DEPRECATED_GCC_POISON == 1)
+#pragma GCC poison SCULPT_SYMM_X SCULPT_SYMM_Y SCULPT_SYMM_Z SCULPT_SYMMETRY_FEATHER
+#endif
+
+
/* ImagePaintSettings.flag */
#define IMAGEPAINT_DRAWING 1
// #define IMAGEPAINT_DRAW_TOOL 2 // deprecated